@@ -6,7 +6,7 @@ authenticator = IAMAuthenticator('your apikey')
 assistant = AssistantV2(
     version='2018-09-20',
     authenticator=authenticator)
-assistant.set_service_url('https://gateway.watsonplatform.net/assistant/api')
+assistant.set_service_url('https://api.us-south.assistant.watson.cloud.ibm.com')
 
 #########################
 # Sessions
@@ -31,3 +31,8 @@ message = assistant.message(
         }
     }).get_result()
 print(json.dumps(message, indent=2))
+
+# logs = assistant.list_logs(
+#     "<YOUR ASSISTANT ID>"
+# )
+# print(json.dumps(logs, indent=2))
