@@ -1,6 +1,6 @@
 # coding: utf-8
 
-# (C) Copyright IBM Corp. 2016, 2020.
+# (C) Copyright IBM Corp. 2016, 2021.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,9 +13,23 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
+# IBM OpenAPI SDK Code Generator Version: 3.38.0-07189efd-20210827-205025
 """
-The IBM Watson&trade; Personality Insights service enables applications to derive insights
-from social media, enterprise data, or other digital communications. The service uses
+IBM Watson&trade; Personality Insights is discontinued. Existing instances are supported
+until 1 December 2021, but as of 1 December 2020, you cannot create new instances. Any
+instance that exists on 1 December 2021 will be deleted.<br/><br/>No direct replacement
+exists for Personality Insights. However, you can consider using [IBM Watson&trade;
+Natural Language
+Understanding](https://cloud.ibm.com/docs/natural-language-understanding?topic=natural-language-understanding-about)
+on IBM Cloud&reg; as part of a replacement analytic workflow for your Personality Insights
+use cases. You can use Natural Language Understanding to extract data and insights from
+text, such as keywords, categories, sentiment, emotion, and syntax. For more information
+about the personality models in Personality Insights, see [The science behind the
+service](https://cloud.ibm.com/docs/personality-insights?topic=personality-insights-science).
+{: deprecated}
+The IBM Watson Personality Insights service enables applications to derive insights from
+social media, enterprise data, or other digital communications. The service uses
 linguistic analytics to infer individuals' intrinsic personality characteristics,
 including Big Five, Needs, and Values, from digital communications such as email, text
 messages, tweets, and forum posts.
@@ -31,17 +45,21 @@ preferences](https://cloud.ibm.com/docs/personality-insights?topic=personality-i
 **Note:** Request logging is disabled for the Personality Insights service. Regardless of
 whether you set the `X-Watson-Learning-Opt-Out` request header, the service does not log
 or retain data from requests and responses.
+
+API Version: 3.4.4
+See: https://cloud.ibm.com/docs/personality-insights
 """
 
-import json
-from ibm_cloud_sdk_core.authenticators.authenticator import Authenticator
-from .common import get_sdk_headers
 from enum import Enum
-from ibm_cloud_sdk_core import BaseService
-from ibm_cloud_sdk_core import DetailedResponse
+from typing import Dict, List, TextIO, Union
+import json
+
+from ibm_cloud_sdk_core import BaseService, DetailedResponse
+from ibm_cloud_sdk_core.authenticators.authenticator import Authenticator
 from ibm_cloud_sdk_core.get_authenticator import get_authenticator_from_environment
-from typing import Dict
-from typing import List
+from ibm_cloud_sdk_core.utils import convert_model
+
+from .common import get_sdk_headers
 
 ##############################################################################
 # Service
@@ -51,39 +69,36 @@ from typing import List
 class PersonalityInsightsV3(BaseService):
     """The Personality Insights V3 service."""
 
-    DEFAULT_SERVICE_URL = 'https://gateway.watsonplatform.net/personality-insights/api'
+    DEFAULT_SERVICE_URL = 'https://api.us-south.personality-insights.watson.cloud.ibm.com'
     DEFAULT_SERVICE_NAME = 'personality_insights'
 
     def __init__(
-            self,
-            version: str,
-            authenticator: Authenticator = None,
-            service_name: str = DEFAULT_SERVICE_NAME,
+        self,
+        version: str,
+        authenticator: Authenticator = None,
+        service_name: str = DEFAULT_SERVICE_NAME,
     ) -> None:
         """
         Construct a new client for the Personality Insights service.
 
-        :param str version: The API version date to use with the service, in
-               "YYYY-MM-DD" format. Whenever the API is changed in a backwards
-               incompatible way, a new minor version of the API is released.
-               The service uses the API version for the date you specify, or
-               the most recent version before that date. Note that you should
-               not programmatically specify the current date at runtime, in
-               case the API has been updated since your application's release.
-               Instead, specify a version date that is compatible with your
-               application, and don't change it until your application is
-               ready for a later version.
+        :param str version: Release date of the version of the API you want to use.
+               Specify dates in YYYY-MM-DD format. The current version is `2017-10-13`.
 
         :param Authenticator authenticator: The authenticator specifies the authentication mechanism.
                Get up to date information from https://github.com/IBM/python-sdk-core/blob/master/README.md
                about initializing the authenticator of your choice.
         """
+        print(
+            'warning: On 1 December 2021, Personality Insights will no longer be available. For more information, see https://github.com/watson-developer-cloud/python-sdk/tree/master#personality-insights-deprecation.'
+        )
+        if version is None:
+            raise ValueError('version must be provided')
+
         if not authenticator:
             authenticator = get_authenticator_from_environment(service_name)
         BaseService.__init__(self,
                              service_url=self.DEFAULT_SERVICE_URL,
-                             authenticator=authenticator,
-                             disable_ssl_verification=False)
+                             authenticator=authenticator)
         self.version = version
         self.configure_service(service_name)
 
@@ -92,7 +107,7 @@ class PersonalityInsightsV3(BaseService):
     #########################
 
     def profile(self,
-                content: object,
+                content: Union['Content', str, TextIO],
                 accept: str,
                 *,
                 content_type: str = None,
@@ -101,7 +116,7 @@ class PersonalityInsightsV3(BaseService):
                 raw_scores: bool = None,
                 csv_headers: bool = None,
                 consumption_preferences: bool = None,
-                **kwargs) -> 'DetailedResponse':
+                **kwargs) -> DetailedResponse:
         """
         Get profile.
 
@@ -176,7 +191,7 @@ class PersonalityInsightsV3(BaseService):
                consumption preferences are returned.
         :param dict headers: A `dict` containing the request headers
         :return: A `DetailedResponse` containing the result, headers and HTTP status code.
-        :rtype: DetailedResponse
+        :rtype: DetailedResponse with `dict` result representing a `Profile` object
         """
 
         if content is None:
@@ -184,16 +199,14 @@ class PersonalityInsightsV3(BaseService):
         if accept is None:
             raise ValueError('accept must be provided')
         if isinstance(content, Content):
-            content = self._convert_model(content)
-
+            content = convert_model(content)
+            content_type = content_type or 'application/json'
         headers = {
             'Accept': accept,
             'Content-Type': content_type,
             'Content-Language': content_language,
             'Accept-Language': accept_language
         }
-        if 'headers' in kwargs:
-            headers.update(kwargs.get('headers'))
         sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
                                       service_version='V3',
                                       operation_id='profile')
@@ -206,11 +219,16 @@ class PersonalityInsightsV3(BaseService):
             'consumption_preferences': consumption_preferences
         }
 
-        if content_type == 'application/json' and isinstance(content, dict):
+        if isinstance(content, dict):
             data = json.dumps(content)
+            if content_type is None:
+                headers['Content-Type'] = 'application/json'
         else:
             data = content
 
+        if 'headers' in kwargs:
+            headers.update(kwargs.get('headers'))
+
         url = '/v3/profile'
         request = self.prepare_request(method='POST',
                                        url=url,
@@ -218,13 +236,16 @@ class PersonalityInsightsV3(BaseService):
                                        params=params,
                                        data=data)
 
-        response = self.send(request)
+        response = self.send(request, **kwargs)
         return response
 
 
-class ProfileEnums(object):
+class ProfileEnums:
+    """
+    Enums for profile parameters.
+    """
 
-    class Accept(Enum):
+    class Accept(str, Enum):
         """
         The type of the response. For more information, see **Accept types** in the method
         description.
@@ -232,7 +253,7 @@ class ProfileEnums(object):
         APPLICATION_JSON = 'application/json'
         TEXT_CSV = 'text/csv'
 
-    class ContentType(Enum):
+    class ContentType(str, Enum):
         """
         The type of the input. For more information, see **Content types** in the method
         description.
@@ -241,7 +262,7 @@ class ProfileEnums(object):
         TEXT_HTML = 'text/html'
         TEXT_PLAIN = 'text/plain'
 
-    class ContentLanguage(Enum):
+    class ContentLanguage(str, Enum):
         """
         The language of the input text for the request: Arabic, English, Japanese, Korean,
         or Spanish. Regional variants are treated as their parent language; for example,
@@ -261,7 +282,7 @@ class ProfileEnums(object):
         JA = 'ja'
         KO = 'ko'
 
-    class AcceptLanguage(Enum):
+    class AcceptLanguage(str, Enum):
         """
         The desired language of the response. For two-character arguments, regional
         variants are treated as their parent language; for example, `en-US` is interpreted
@@ -324,12 +345,6 @@ class Behavior():
     def from_dict(cls, _dict: Dict) -> 'Behavior':
         """Initialize a Behavior object from a json dictionary."""
         args = {}
-        valid_keys = ['trait_id', 'name', 'category', 'percentage']
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class Behavior: '
-                + ', '.join(bad_keys))
         if 'trait_id' in _dict:
             args['trait_id'] = _dict.get('trait_id')
         else:
@@ -376,7 +391,7 @@ class Behavior():
 
     def __str__(self) -> str:
         """Return a `str` version of this Behavior object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'Behavior') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -432,12 +447,6 @@ class ConsumptionPreferences():
     def from_dict(cls, _dict: Dict) -> 'ConsumptionPreferences':
         """Initialize a ConsumptionPreferences object from a json dictionary."""
         args = {}
-        valid_keys = ['consumption_preference_id', 'name', 'score']
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class ConsumptionPreferences: '
-                + ', '.join(bad_keys))
         if 'consumption_preference_id' in _dict:
             args['consumption_preference_id'] = _dict.get(
                 'consumption_preference_id')
@@ -482,7 +491,7 @@ class ConsumptionPreferences():
 
     def __str__(self) -> str:
         """Return a `str` version of this ConsumptionPreferences object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'ConsumptionPreferences') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -507,9 +516,9 @@ class ConsumptionPreferencesCategory():
           inferred from the input text for the individual preferences of the category.
     """
 
-    def __init__(self, consumption_preference_category_id: str, name: str,
-                 consumption_preferences: List['ConsumptionPreferences']
-                ) -> None:
+    def __init__(
+            self, consumption_preference_category_id: str, name: str,
+            consumption_preferences: List['ConsumptionPreferences']) -> None:
         """
         Initialize a ConsumptionPreferencesCategory object.
 
@@ -530,15 +539,6 @@ class ConsumptionPreferencesCategory():
     def from_dict(cls, _dict: Dict) -> 'ConsumptionPreferencesCategory':
         """Initialize a ConsumptionPreferencesCategory object from a json dictionary."""
         args = {}
-        valid_keys = [
-            'consumption_preference_category_id', 'name',
-            'consumption_preferences'
-        ]
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class ConsumptionPreferencesCategory: '
-                + ', '.join(bad_keys))
         if 'consumption_preference_category_id' in _dict:
             args['consumption_preference_category_id'] = _dict.get(
                 'consumption_preference_category_id')
@@ -554,8 +554,8 @@ class ConsumptionPreferencesCategory():
             )
         if 'consumption_preferences' in _dict:
             args['consumption_preferences'] = [
-                ConsumptionPreferences._from_dict(x)
-                for x in (_dict.get('consumption_preferences'))
+                ConsumptionPreferences.from_dict(x)
+                for x in _dict.get('consumption_preferences')
             ]
         else:
             raise ValueError(
@@ -580,7 +580,7 @@ class ConsumptionPreferencesCategory():
         if hasattr(self, 'consumption_preferences'
                   ) and self.consumption_preferences is not None:
             _dict['consumption_preferences'] = [
-                x._to_dict() for x in self.consumption_preferences
+                x.to_dict() for x in self.consumption_preferences
             ]
         return _dict
 
@@ -590,7 +590,7 @@ class ConsumptionPreferencesCategory():
 
     def __str__(self) -> str:
         """Return a `str` version of this ConsumptionPreferencesCategory object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'ConsumptionPreferencesCategory') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -624,15 +624,9 @@ class Content():
     def from_dict(cls, _dict: Dict) -> 'Content':
         """Initialize a Content object from a json dictionary."""
         args = {}
-        valid_keys = ['content_items', 'contentItems']
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class Content: ' +
-                ', '.join(bad_keys))
         if 'contentItems' in _dict:
             args['content_items'] = [
-                ContentItem._from_dict(x) for x in (_dict.get('contentItems'))
+                ContentItem.from_dict(x) for x in _dict.get('contentItems')
             ]
         else:
             raise ValueError(
@@ -649,7 +643,7 @@ class Content():
         """Return a json dictionary representing this model."""
         _dict = {}
         if hasattr(self, 'content_items') and self.content_items is not None:
-            _dict['contentItems'] = [x._to_dict() for x in self.content_items]
+            _dict['contentItems'] = [x.to_dict() for x in self.content_items]
         return _dict
 
     def _to_dict(self):
@@ -658,7 +652,7 @@ class Content():
 
     def __str__(self) -> str:
         """Return a `str` version of this Content object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'Content') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -766,15 +760,6 @@ class ContentItem():
     def from_dict(cls, _dict: Dict) -> 'ContentItem':
         """Initialize a ContentItem object from a json dictionary."""
         args = {}
-        valid_keys = [
-            'content', 'id', 'created', 'updated', 'contenttype', 'language',
-            'parentid', 'reply', 'forward'
-        ]
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class ContentItem: '
-                + ', '.join(bad_keys))
         if 'content' in _dict:
             args['content'] = _dict.get('content')
         else:
@@ -832,7 +817,7 @@ class ContentItem():
 
     def __str__(self) -> str:
         """Return a `str` version of this ContentItem object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'ContentItem') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -844,15 +829,15 @@ class ContentItem():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-    class ContenttypeEnum(Enum):
+    class ContenttypeEnum(str, Enum):
         """
         The MIME type of the content. The default is plain text. The tags are stripped
         from HTML content before it is analyzed; plain text is processed as submitted.
         """
-        TEXT_PLAIN = "text/plain"
-        TEXT_HTML = "text/html"
+        TEXT_PLAIN = 'text/plain'
+        TEXT_HTML = 'text/html'
 
-    class LanguageEnum(Enum):
+    class LanguageEnum(str, Enum):
         """
         The language identifier (two-letter ISO 639-1 identifier) for the language of the
         content item. The default is `en` (English). Regional variants are treated as
@@ -864,11 +849,11 @@ class ContentItem():
         different language are ignored. You can specify any combination of languages for
         the input and response content.
         """
-        AR = "ar"
-        EN = "en"
-        ES = "es"
-        JA = "ja"
-        KO = "ko"
+        AR = 'ar'
+        EN = 'en'
+        ES = 'es'
+        JA = 'ja'
+        KO = 'ko'
 
 
 class Profile():
@@ -903,18 +888,19 @@ class Profile():
           no warnings.
     """
 
-    def __init__(self,
-                 processed_language: str,
-                 word_count: int,
-                 personality: List['Trait'],
-                 needs: List['Trait'],
-                 values: List['Trait'],
-                 warnings: List['Warning'],
-                 *,
-                 word_count_message: str = None,
-                 behavior: List['Behavior'] = None,
-                 consumption_preferences: List[
-                     'ConsumptionPreferencesCategory'] = None) -> None:
+    def __init__(
+        self,
+        processed_language: str,
+        word_count: int,
+        personality: List['Trait'],
+        needs: List['Trait'],
+        values: List['Trait'],
+        warnings: List['Warning'],
+        *,
+        word_count_message: str = None,
+        behavior: List['Behavior'] = None,
+        consumption_preferences: List['ConsumptionPreferencesCategory'] = None
+    ) -> None:
         """
         Initialize a Profile object.
 
@@ -961,16 +947,6 @@ class Profile():
     def from_dict(cls, _dict: Dict) -> 'Profile':
         """Initialize a Profile object from a json dictionary."""
         args = {}
-        valid_keys = [
-            'processed_language', 'word_count', 'word_count_message',
-            'personality', 'needs', 'values', 'behavior',
-            'consumption_preferences', 'warnings'
-        ]
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class Profile: ' +
-                ', '.join(bad_keys))
         if 'processed_language' in _dict:
             args['processed_language'] = _dict.get('processed_language')
         else:
@@ -986,35 +962,33 @@ class Profile():
             args['word_count_message'] = _dict.get('word_count_message')
         if 'personality' in _dict:
             args['personality'] = [
-                Trait._from_dict(x) for x in (_dict.get('personality'))
+                Trait.from_dict(x) for x in _dict.get('personality')
             ]
         else:
             raise ValueError(
                 'Required property \'personality\' not present in Profile JSON')
         if 'needs' in _dict:
-            args['needs'] = [Trait._from_dict(x) for x in (_dict.get('needs'))]
+            args['needs'] = [Trait.from_dict(x) for x in _dict.get('needs')]
         else:
             raise ValueError(
                 'Required property \'needs\' not present in Profile JSON')
         if 'values' in _dict:
-            args['values'] = [
-                Trait._from_dict(x) for x in (_dict.get('values'))
-            ]
+            args['values'] = [Trait.from_dict(x) for x in _dict.get('values')]
         else:
             raise ValueError(
                 'Required property \'values\' not present in Profile JSON')
         if 'behavior' in _dict:
             args['behavior'] = [
-                Behavior._from_dict(x) for x in (_dict.get('behavior'))
+                Behavior.from_dict(x) for x in _dict.get('behavior')
             ]
         if 'consumption_preferences' in _dict:
             args['consumption_preferences'] = [
-                ConsumptionPreferencesCategory._from_dict(x)
-                for x in (_dict.get('consumption_preferences'))
+                ConsumptionPreferencesCategory.from_dict(x)
+                for x in _dict.get('consumption_preferences')
             ]
         if 'warnings' in _dict:
             args['warnings'] = [
-                Warning._from_dict(x) for x in (_dict.get('warnings'))
+                Warning.from_dict(x) for x in _dict.get('warnings')
             ]
         else:
             raise ValueError(
@@ -1040,20 +1014,20 @@ class Profile():
                 'word_count_message') and self.word_count_message is not None:
             _dict['word_count_message'] = self.word_count_message
         if hasattr(self, 'personality') and self.personality is not None:
-            _dict['personality'] = [x._to_dict() for x in self.personality]
+            _dict['personality'] = [x.to_dict() for x in self.personality]
         if hasattr(self, 'needs') and self.needs is not None:
-            _dict['needs'] = [x._to_dict() for x in self.needs]
+            _dict['needs'] = [x.to_dict() for x in self.needs]
         if hasattr(self, 'values') and self.values is not None:
-            _dict['values'] = [x._to_dict() for x in self.values]
+            _dict['values'] = [x.to_dict() for x in self.values]
         if hasattr(self, 'behavior') and self.behavior is not None:
-            _dict['behavior'] = [x._to_dict() for x in self.behavior]
+            _dict['behavior'] = [x.to_dict() for x in self.behavior]
         if hasattr(self, 'consumption_preferences'
                   ) and self.consumption_preferences is not None:
             _dict['consumption_preferences'] = [
-                x._to_dict() for x in self.consumption_preferences
+                x.to_dict() for x in self.consumption_preferences
             ]
         if hasattr(self, 'warnings') and self.warnings is not None:
-            _dict['warnings'] = [x._to_dict() for x in self.warnings]
+            _dict['warnings'] = [x.to_dict() for x in self.warnings]
         return _dict
 
     def _to_dict(self):
@@ -1062,7 +1036,7 @@ class Profile():
 
     def __str__(self) -> str:
         """Return a `str` version of this Profile object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'Profile') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -1074,15 +1048,15 @@ class Profile():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-    class ProcessedLanguageEnum(Enum):
+    class ProcessedLanguageEnum(str, Enum):
         """
         The language model that was used to process the input.
         """
-        AR = "ar"
-        EN = "en"
-        ES = "es"
-        JA = "ja"
-        KO = "ko"
+        AR = 'ar'
+        EN = 'en'
+        ES = 'es'
+        JA = 'ja'
+        KO = 'ko'
 
 
 class Trait():
@@ -1182,15 +1156,6 @@ class Trait():
     def from_dict(cls, _dict: Dict) -> 'Trait':
         """Initialize a Trait object from a json dictionary."""
         args = {}
-        valid_keys = [
-            'trait_id', 'name', 'category', 'percentile', 'raw_score',
-            'significant', 'children'
-        ]
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class Trait: ' +
-                ', '.join(bad_keys))
         if 'trait_id' in _dict:
             args['trait_id'] = _dict.get('trait_id')
         else:
@@ -1217,7 +1182,7 @@ class Trait():
             args['significant'] = _dict.get('significant')
         if 'children' in _dict:
             args['children'] = [
-                Trait._from_dict(x) for x in (_dict.get('children'))
+                Trait.from_dict(x) for x in _dict.get('children')
             ]
         return cls(**args)
 
@@ -1242,7 +1207,7 @@ class Trait():
         if hasattr(self, 'significant') and self.significant is not None:
             _dict['significant'] = self.significant
         if hasattr(self, 'children') and self.children is not None:
-            _dict['children'] = [x._to_dict() for x in self.children]
+            _dict['children'] = [x.to_dict() for x in self.children]
         return _dict
 
     def _to_dict(self):
@@ -1251,7 +1216,7 @@ class Trait():
 
     def __str__(self) -> str:
         """Return a `str` version of this Trait object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'Trait') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -1263,14 +1228,14 @@ class Trait():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-    class CategoryEnum(Enum):
+    class CategoryEnum(str, Enum):
         """
         The category of the characteristic: `personality` for Big Five personality
         characteristics, `needs` for Needs, and `values` for Values.
         """
-        PERSONALITY = "personality"
-        NEEDS = "needs"
-        VALUES = "values"
+        PERSONALITY = 'personality'
+        NEEDS = 'needs'
+        VALUES = 'values'
 
 
 class Warning():
@@ -1323,12 +1288,6 @@ class Warning():
     def from_dict(cls, _dict: Dict) -> 'Warning':
         """Initialize a Warning object from a json dictionary."""
         args = {}
-        valid_keys = ['warning_id', 'message']
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class Warning: ' +
-                ', '.join(bad_keys))
         if 'warning_id' in _dict:
             args['warning_id'] = _dict.get('warning_id')
         else:
@@ -1361,7 +1320,7 @@ class Warning():
 
     def __str__(self) -> str:
         """Return a `str` version of this Warning object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'Warning') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -1373,11 +1332,11 @@ class Warning():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-    class WarningIdEnum(Enum):
+    class WarningIdEnum(str, Enum):
         """
         The identifier of the warning message.
         """
-        WORD_COUNT_MESSAGE = "WORD_COUNT_MESSAGE"
-        JSON_AS_TEXT = "JSON_AS_TEXT"
-        CONTENT_TRUNCATED = "CONTENT_TRUNCATED"
-        PARTIAL_TEXT_USED = "PARTIAL_TEXT_USED"
+        WORD_COUNT_MESSAGE = 'WORD_COUNT_MESSAGE'
+        JSON_AS_TEXT = 'JSON_AS_TEXT'
+        CONTENT_TRUNCATED = 'CONTENT_TRUNCATED'
+        PARTIAL_TEXT_USED = 'PARTIAL_TEXT_USED'
