@@ -13,25 +13,33 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
+# IBM OpenAPI SDK Code Generator Version: 3.38.0-07189efd-20210827-205025
 """
-The IBM Watson&trade; Visual Recognition service uses deep learning algorithms to identify
-scenes and objects in images that you upload to the service. You can create and train a
-custom classifier to identify subjects that suit your needs.
+IBM Watson&trade; Visual Recognition is discontinued. Existing instances are supported
+until 1 December 2021, but as of 7 January 2021, you can't create instances. Any instance
+that is provisioned on 1 December 2021 will be deleted.
+{: deprecated}
+The IBM Watson Visual Recognition service uses deep learning algorithms to identify scenes
+and objects in images that you upload to the service. You can create and train a custom
+classifier to identify subjects that suit your needs.
+
+API Version: 3.0
+See: https://cloud.ibm.com/docs/visual-recognition
 """
 
-import json
-from ibm_cloud_sdk_core.authenticators.authenticator import Authenticator
-from .common import get_sdk_headers
 from datetime import datetime
 from enum import Enum
-from ibm_cloud_sdk_core import BaseService
-from ibm_cloud_sdk_core import DetailedResponse
-from ibm_cloud_sdk_core import datetime_to_string, string_to_datetime
-from ibm_cloud_sdk_core.get_authenticator import get_authenticator_from_environment
 from os.path import basename
-from typing import BinaryIO
-from typing import Dict
-from typing import List
+from typing import BinaryIO, Dict, List
+import json
+
+from ibm_cloud_sdk_core import BaseService, DetailedResponse
+from ibm_cloud_sdk_core.authenticators.authenticator import Authenticator
+from ibm_cloud_sdk_core.get_authenticator import get_authenticator_from_environment
+from ibm_cloud_sdk_core.utils import datetime_to_string, string_to_datetime
+
+from .common import get_sdk_headers
 
 ##############################################################################
 # Service
@@ -41,39 +49,36 @@ from typing import List
 class VisualRecognitionV3(BaseService):
     """The Visual Recognition V3 service."""
 
-    DEFAULT_SERVICE_URL = 'https://gateway.watsonplatform.net/visual-recognition/api'
+    DEFAULT_SERVICE_URL = 'https://api.us-south.visual-recognition.watson.cloud.ibm.com'
     DEFAULT_SERVICE_NAME = 'visual_recognition'
 
     def __init__(
-            self,
-            version: str,
-            authenticator: Authenticator = None,
-            service_name: str = DEFAULT_SERVICE_NAME,
+        self,
+        version: str,
+        authenticator: Authenticator = None,
+        service_name: str = DEFAULT_SERVICE_NAME,
     ) -> None:
         """
         Construct a new client for the Visual Recognition service.
 
-        :param str version: The API version date to use with the service, in
-               "YYYY-MM-DD" format. Whenever the API is changed in a backwards
-               incompatible way, a new minor version of the API is released.
-               The service uses the API version for the date you specify, or
-               the most recent version before that date. Note that you should
-               not programmatically specify the current date at runtime, in
-               case the API has been updated since your application's release.
-               Instead, specify a version date that is compatible with your
-               application, and don't change it until your application is
-               ready for a later version.
+        :param str version: Release date of the API version you want to use.
+               Specify dates in YYYY-MM-DD format. The current version is `2018-03-19`.
 
         :param Authenticator authenticator: The authenticator specifies the authentication mechanism.
                Get up to date information from https://github.com/IBM/python-sdk-core/blob/master/README.md
                about initializing the authenticator of your choice.
         """
+        print(
+            'warning: On 1 December 2021, Visual Recognition will no longer be available. For more information, see https://github.com/watson-developer-cloud/python-sdk/tree/master#visual-recognition-deprecation.'
+        )
+        if version is None:
+            raise ValueError('version must be provided')
+
         if not authenticator:
             authenticator = get_authenticator_from_environment(service_name)
         BaseService.__init__(self,
                              service_url=self.DEFAULT_SERVICE_URL,
-                             authenticator=authenticator,
-                             disable_ssl_verification=False)
+                             authenticator=authenticator)
         self.version = version
         self.configure_service(service_name)
 
@@ -88,16 +93,16 @@ class VisualRecognitionV3(BaseService):
                  images_file_content_type: str = None,
                  url: str = None,
                  threshold: float = None,
-                 owners: str = None,
-                 classifier_ids: str = None,
+                 owners: List[str] = None,
+                 classifier_ids: List[str] = None,
                  accept_language: str = None,
-                 **kwargs) -> 'DetailedResponse':
+                 **kwargs) -> DetailedResponse:
         """
         Classify images.
 
         Classify images with built-in or custom classifiers.
 
-        :param TextIO images_file: (optional) An image file (.gif, .jpg, .png,
+        :param BinaryIO images_file: (optional) An image file (.gif, .jpg, .png,
                .tif) or .zip file with images. Maximum image size is 10 MB. Include no
                more than 20 images and limit the .zip file to 100 MB. Encode the image and
                .zip file names in UTF-8 if they contain non-ASCII characters. The service
@@ -137,12 +142,10 @@ class VisualRecognitionV3(BaseService):
                response. See the response for details.
         :param dict headers: A `dict` containing the request headers
         :return: A `DetailedResponse` containing the result, headers and HTTP status code.
-        :rtype: DetailedResponse
+        :rtype: DetailedResponse with `dict` result representing a `ClassifiedImages` object
         """
 
         headers = {'Accept-Language': accept_language}
-        if 'headers' in kwargs:
-            headers.update(kwargs.get('headers'))
         sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
                                       service_version='V3',
                                       operation_id='classify')
@@ -160,17 +163,20 @@ class VisualRecognitionV3(BaseService):
                                               images_file_content_type or
                                               'application/octet-stream')))
         if url:
-            url = str(url)
             form_data.append(('url', (None, url, 'text/plain')))
         if threshold:
-            threshold = str(threshold)
-            form_data.append(('threshold', (None, threshold, 'text/plain')))
+            form_data.append(
+                ('threshold', (None, str(threshold), 'text/plain')))
         if owners:
             owners = self._convert_list(owners)
             form_data.append(('owners', (None, owners, 'text/plain')))
         if classifier_ids:
             classifier_ids = self._convert_list(classifier_ids)
-            form_data.append(('classifier_ids', (None, classifier_ids, 'text/plain')))
+            form_data.append(
+                ('classifier_ids', (None, classifier_ids, 'text/plain')))
+        if 'headers' in kwargs:
+            headers.update(kwargs.get('headers'))
+        headers['Accept'] = 'application/json'
 
         url = '/v3/classify'
         request = self.prepare_request(method='POST',
@@ -179,7 +185,7 @@ class VisualRecognitionV3(BaseService):
                                        params=params,
                                        files=form_data)
 
-        response = self.send(request)
+        response = self.send(request, **kwargs)
         return response
 
     #########################
@@ -188,11 +194,11 @@ class VisualRecognitionV3(BaseService):
 
     def create_classifier(self,
                           name: str,
-                          positive_examples: BinaryIO,
+                          positive_examples: Dict[str, BinaryIO],
                           *,
                           negative_examples: BinaryIO = None,
                           negative_examples_filename: str = None,
-                          **kwargs) -> 'DetailedResponse':
+                          **kwargs) -> DetailedResponse:
         """
         Create a classifier.
 
@@ -223,7 +229,7 @@ class VisualRecognitionV3(BaseService):
                image resolution is 32X32 pixels. The maximum number of images is 10,000
                images or 100 MB per .zip file.
                Encode special characters in the file name in UTF-8.
-        :param TextIO negative_examples: (optional) A .zip file of images that do
+        :param BinaryIO negative_examples: (optional) A .zip file of images that do
                not depict the visual subject of any of the classes of the new classifier.
                Must contain a minimum of 10 images.
                Encode special characters in the file name in UTF-8.
@@ -231,17 +237,14 @@ class VisualRecognitionV3(BaseService):
                negative_examples.
         :param dict headers: A `dict` containing the request headers
         :return: A `DetailedResponse` containing the result, headers and HTTP status code.
-        :rtype: DetailedResponse
+        :rtype: DetailedResponse with `dict` result representing a `Classifier` object
         """
 
         if name is None:
             raise ValueError('name must be provided')
         if not positive_examples:
             raise ValueError('positive_examples must be provided')
-
         headers = {}
-        if 'headers' in kwargs:
-            headers.update(kwargs.get('headers'))
         sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
                                       service_version='V3',
                                       operation_id='create_classifier')
@@ -250,15 +253,15 @@ class VisualRecognitionV3(BaseService):
         params = {'version': self.version}
 
         form_data = []
-        name = str(name)
         form_data.append(('name', (None, name, 'text/plain')))
         for key in positive_examples.keys():
             part_name = '%s_positive_examples' % (key)
             value = positive_examples[key]
+            filename = None
             if hasattr(value, 'name'):
                 filename = basename(value.name)
-                form_data.append(
-                    (part_name, (filename, value, 'application/octet-stream')))
+            form_data.append(
+                (part_name, (filename, value, 'application/octet-stream')))
         if negative_examples:
             if not negative_examples_filename and hasattr(
                     negative_examples, 'name'):
@@ -269,6 +272,10 @@ class VisualRecognitionV3(BaseService):
                               (negative_examples_filename, negative_examples,
                                'application/octet-stream')))
 
+        if 'headers' in kwargs:
+            headers.update(kwargs.get('headers'))
+        headers['Accept'] = 'application/json'
+
         url = '/v3/classifiers'
         request = self.prepare_request(method='POST',
                                        url=url,
@@ -276,11 +283,13 @@ class VisualRecognitionV3(BaseService):
                                        params=params,
                                        files=form_data)
 
-        response = self.send(request)
+        response = self.send(request, **kwargs)
         return response
 
-    def list_classifiers(self, *, verbose: bool = None,
-                         **kwargs) -> 'DetailedResponse':
+    def list_classifiers(self,
+                         *,
+                         verbose: bool = None,
+                         **kwargs) -> DetailedResponse:
         """
         Retrieve a list of classifiers.
 
@@ -288,12 +297,10 @@ class VisualRecognitionV3(BaseService):
                classifiers. Omit this parameter to return a brief list of classifiers.
         :param dict headers: A `dict` containing the request headers
         :return: A `DetailedResponse` containing the result, headers and HTTP status code.
-        :rtype: DetailedResponse
+        :rtype: DetailedResponse with `dict` result representing a `Classifiers` object
         """
 
         headers = {}
-        if 'headers' in kwargs:
-            headers.update(kwargs.get('headers'))
         sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
                                       service_version='V3',
                                       operation_id='list_classifiers')
@@ -301,17 +308,20 @@ class VisualRecognitionV3(BaseService):
 
         params = {'version': self.version, 'verbose': verbose}
 
+        if 'headers' in kwargs:
+            headers.update(kwargs.get('headers'))
+        headers['Accept'] = 'application/json'
+
         url = '/v3/classifiers'
         request = self.prepare_request(method='GET',
                                        url=url,
                                        headers=headers,
                                        params=params)
 
-        response = self.send(request)
+        response = self.send(request, **kwargs)
         return response
 
-    def get_classifier(self, classifier_id: str,
-                       **kwargs) -> 'DetailedResponse':
+    def get_classifier(self, classifier_id: str, **kwargs) -> DetailedResponse:
         """
         Retrieve classifier details.
 
@@ -320,15 +330,12 @@ class VisualRecognitionV3(BaseService):
         :param str classifier_id: The ID of the classifier.
         :param dict headers: A `dict` containing the request headers
         :return: A `DetailedResponse` containing the result, headers and HTTP status code.
-        :rtype: DetailedResponse
+        :rtype: DetailedResponse with `dict` result representing a `Classifier` object
         """
 
         if classifier_id is None:
             raise ValueError('classifier_id must be provided')
-
         headers = {}
-        if 'headers' in kwargs:
-            headers.update(kwargs.get('headers'))
         sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
                                       service_version='V3',
                                       operation_id='get_classifier')
@@ -336,23 +343,29 @@ class VisualRecognitionV3(BaseService):
 
         params = {'version': self.version}
 
-        url = '/v3/classifiers/{0}'.format(
-            *self._encode_path_vars(classifier_id))
+        if 'headers' in kwargs:
+            headers.update(kwargs.get('headers'))
+        headers['Accept'] = 'application/json'
+
+        path_param_keys = ['classifier_id']
+        path_param_values = self.encode_path_vars(classifier_id)
+        path_param_dict = dict(zip(path_param_keys, path_param_values))
+        url = '/v3/classifiers/{classifier_id}'.format(**path_param_dict)
         request = self.prepare_request(method='GET',
                                        url=url,
                                        headers=headers,
                                        params=params)
 
-        response = self.send(request)
+        response = self.send(request, **kwargs)
         return response
 
     def update_classifier(self,
                           classifier_id: str,
                           *,
-                          positive_examples: BinaryIO = {},
+                          positive_examples: Dict[str, BinaryIO] = {},
                           negative_examples: BinaryIO = None,
                           negative_examples_filename: str = None,
-                          **kwargs) -> 'DetailedResponse':
+                          **kwargs) -> DetailedResponse:
         """
         Update a classifier.
 
@@ -387,7 +400,7 @@ class VisualRecognitionV3(BaseService):
                image resolution is 32X32 pixels. The maximum number of images is 10,000
                images or 100 MB per .zip file.
                Encode special characters in the file name in UTF-8.
-        :param TextIO negative_examples: (optional) A .zip file of images that do
+        :param BinaryIO negative_examples: (optional) A .zip file of images that do
                not depict the visual subject of any of the classes of the new classifier.
                Must contain a minimum of 10 images.
                Encode special characters in the file name in UTF-8.
@@ -395,15 +408,12 @@ class VisualRecognitionV3(BaseService):
                negative_examples.
         :param dict headers: A `dict` containing the request headers
         :return: A `DetailedResponse` containing the result, headers and HTTP status code.
-        :rtype: DetailedResponse
+        :rtype: DetailedResponse with `dict` result representing a `Classifier` object
         """
 
         if classifier_id is None:
             raise ValueError('classifier_id must be provided')
-
         headers = {}
-        if 'headers' in kwargs:
-            headers.update(kwargs.get('headers'))
         sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
                                       service_version='V3',
                                       operation_id='update_classifier')
@@ -415,10 +425,11 @@ class VisualRecognitionV3(BaseService):
         for key in positive_examples.keys():
             part_name = '%s_positive_examples' % (key)
             value = positive_examples[key]
+            filename = None
             if hasattr(value, 'name'):
                 filename = basename(value.name)
-                form_data.append(
-                    (part_name, (filename, value, 'application/octet-stream')))
+            form_data.append(
+                (part_name, (filename, value, 'application/octet-stream')))
         if negative_examples:
             if not negative_examples_filename and hasattr(
                     negative_examples, 'name'):
@@ -429,19 +440,25 @@ class VisualRecognitionV3(BaseService):
                               (negative_examples_filename, negative_examples,
                                'application/octet-stream')))
 
-        url = '/v3/classifiers/{0}'.format(
-            *self._encode_path_vars(classifier_id))
+        if 'headers' in kwargs:
+            headers.update(kwargs.get('headers'))
+        headers['Accept'] = 'application/json'
+
+        path_param_keys = ['classifier_id']
+        path_param_values = self.encode_path_vars(classifier_id)
+        path_param_dict = dict(zip(path_param_keys, path_param_values))
+        url = '/v3/classifiers/{classifier_id}'.format(**path_param_dict)
         request = self.prepare_request(method='POST',
                                        url=url,
                                        headers=headers,
                                        params=params,
                                        files=form_data)
 
-        response = self.send(request)
+        response = self.send(request, **kwargs)
         return response
 
     def delete_classifier(self, classifier_id: str,
-                          **kwargs) -> 'DetailedResponse':
+                          **kwargs) -> DetailedResponse:
         """
         Delete a classifier.
 
@@ -453,10 +470,7 @@ class VisualRecognitionV3(BaseService):
 
         if classifier_id is None:
             raise ValueError('classifier_id must be provided')
-
         headers = {}
-        if 'headers' in kwargs:
-            headers.update(kwargs.get('headers'))
         sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
                                       service_version='V3',
                                       operation_id='delete_classifier')
@@ -464,14 +478,20 @@ class VisualRecognitionV3(BaseService):
 
         params = {'version': self.version}
 
-        url = '/v3/classifiers/{0}'.format(
-            *self._encode_path_vars(classifier_id))
+        if 'headers' in kwargs:
+            headers.update(kwargs.get('headers'))
+        headers['Accept'] = 'application/json'
+
+        path_param_keys = ['classifier_id']
+        path_param_values = self.encode_path_vars(classifier_id)
+        path_param_dict = dict(zip(path_param_keys, path_param_values))
+        url = '/v3/classifiers/{classifier_id}'.format(**path_param_dict)
         request = self.prepare_request(method='DELETE',
                                        url=url,
                                        headers=headers,
                                        params=params)
 
-        response = self.send(request)
+        response = self.send(request, **kwargs)
         return response
 
     #########################
@@ -479,7 +499,7 @@ class VisualRecognitionV3(BaseService):
     #########################
 
     def get_core_ml_model(self, classifier_id: str,
-                          **kwargs) -> 'DetailedResponse':
+                          **kwargs) -> DetailedResponse:
         """
         Retrieve a Core ML model of a classifier.
 
@@ -489,15 +509,12 @@ class VisualRecognitionV3(BaseService):
         :param str classifier_id: The ID of the classifier.
         :param dict headers: A `dict` containing the request headers
         :return: A `DetailedResponse` containing the result, headers and HTTP status code.
-        :rtype: DetailedResponse
+        :rtype: DetailedResponse with `BinaryIO` result
         """
 
         if classifier_id is None:
             raise ValueError('classifier_id must be provided')
-
         headers = {}
-        if 'headers' in kwargs:
-            headers.update(kwargs.get('headers'))
         sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
                                       service_version='V3',
                                       operation_id='get_core_ml_model')
@@ -505,22 +522,28 @@ class VisualRecognitionV3(BaseService):
 
         params = {'version': self.version}
 
-        url = '/v3/classifiers/{0}/core_ml_model'.format(
-            *self._encode_path_vars(classifier_id))
+        if 'headers' in kwargs:
+            headers.update(kwargs.get('headers'))
+        headers['Accept'] = 'application/octet-stream'
+
+        path_param_keys = ['classifier_id']
+        path_param_values = self.encode_path_vars(classifier_id)
+        path_param_dict = dict(zip(path_param_keys, path_param_values))
+        url = '/v3/classifiers/{classifier_id}/core_ml_model'.format(
+            **path_param_dict)
         request = self.prepare_request(method='GET',
                                        url=url,
                                        headers=headers,
                                        params=params)
 
-        response = self.send(request)
+        response = self.send(request, **kwargs)
         return response
 
     #########################
     # User data
     #########################
 
-    def delete_user_data(self, customer_id: str,
-                         **kwargs) -> 'DetailedResponse':
+    def delete_user_data(self, customer_id: str, **kwargs) -> DetailedResponse:
         """
         Delete labeled data.
 
@@ -540,10 +563,7 @@ class VisualRecognitionV3(BaseService):
 
         if customer_id is None:
             raise ValueError('customer_id must be provided')
-
         headers = {}
-        if 'headers' in kwargs:
-            headers.update(kwargs.get('headers'))
         sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
                                       service_version='V3',
                                       operation_id='delete_user_data')
@@ -551,19 +571,26 @@ class VisualRecognitionV3(BaseService):
 
         params = {'version': self.version, 'customer_id': customer_id}
 
+        if 'headers' in kwargs:
+            headers.update(kwargs.get('headers'))
+        headers['Accept'] = 'application/json'
+
         url = '/v3/user_data'
         request = self.prepare_request(method='DELETE',
                                        url=url,
                                        headers=headers,
                                        params=params)
 
-        response = self.send(request)
+        response = self.send(request, **kwargs)
         return response
 
 
-class ClassifyEnums(object):
+class ClassifyEnums:
+    """
+    Enums for classify parameters.
+    """
 
-    class AcceptLanguage(Enum):
+    class AcceptLanguage(str, Enum):
         """
         The desired language of parts of the response. See the response for details.
         """
@@ -604,12 +631,6 @@ class Class():
     def from_dict(cls, _dict: Dict) -> 'Class':
         """Initialize a Class object from a json dictionary."""
         args = {}
-        valid_keys = ['class_', 'class']
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class Class: ' +
-                ', '.join(bad_keys))
         if 'class' in _dict:
             args['class_'] = _dict.get('class')
         else:
@@ -635,7 +656,7 @@ class Class():
 
     def __str__(self) -> str:
         """Return a `str` version of this Class object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'Class') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -666,7 +687,10 @@ class ClassResult():
           identified.
     """
 
-    def __init__(self, class_: str, score: float, *,
+    def __init__(self,
+                 class_: str,
+                 score: float,
+                 *,
                  type_hierarchy: str = None) -> None:
         """
         Initialize a ClassResult object.
@@ -694,12 +718,6 @@ class ClassResult():
     def from_dict(cls, _dict: Dict) -> 'ClassResult':
         """Initialize a ClassResult object from a json dictionary."""
         args = {}
-        valid_keys = ['class_', 'class', 'score', 'type_hierarchy']
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class ClassResult: '
-                + ', '.join(bad_keys))
         if 'class' in _dict:
             args['class_'] = _dict.get('class')
         else:
@@ -736,7 +754,7 @@ class ClassResult():
 
     def __str__(self) -> str:
         """Return a `str` version of this ClassResult object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'ClassResult') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -796,14 +814,6 @@ class ClassifiedImage():
     def from_dict(cls, _dict: Dict) -> 'ClassifiedImage':
         """Initialize a ClassifiedImage object from a json dictionary."""
         args = {}
-        valid_keys = [
-            'source_url', 'resolved_url', 'image', 'error', 'classifiers'
-        ]
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class ClassifiedImage: '
-                + ', '.join(bad_keys))
         if 'source_url' in _dict:
             args['source_url'] = _dict.get('source_url')
         if 'resolved_url' in _dict:
@@ -811,11 +821,10 @@ class ClassifiedImage():
         if 'image' in _dict:
             args['image'] = _dict.get('image')
         if 'error' in _dict:
-            args['error'] = ErrorInfo._from_dict(_dict.get('error'))
+            args['error'] = ErrorInfo.from_dict(_dict.get('error'))
         if 'classifiers' in _dict:
             args['classifiers'] = [
-                ClassifierResult._from_dict(x)
-                for x in (_dict.get('classifiers'))
+                ClassifierResult.from_dict(x) for x in _dict.get('classifiers')
             ]
         else:
             raise ValueError(
@@ -838,9 +847,9 @@ class ClassifiedImage():
         if hasattr(self, 'image') and self.image is not None:
             _dict['image'] = self.image
         if hasattr(self, 'error') and self.error is not None:
-            _dict['error'] = self.error._to_dict()
+            _dict['error'] = self.error.to_dict()
         if hasattr(self, 'classifiers') and self.classifiers is not None:
-            _dict['classifiers'] = [x._to_dict() for x in self.classifiers]
+            _dict['classifiers'] = [x.to_dict() for x in self.classifiers]
         return _dict
 
     def _to_dict(self):
@@ -849,7 +858,7 @@ class ClassifiedImage():
 
     def __str__(self) -> str:
         """Return a `str` version of this ClassifiedImage object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'ClassifiedImage') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -905,21 +914,13 @@ class ClassifiedImages():
     def from_dict(cls, _dict: Dict) -> 'ClassifiedImages':
         """Initialize a ClassifiedImages object from a json dictionary."""
         args = {}
-        valid_keys = [
-            'custom_classes', 'images_processed', 'images', 'warnings'
-        ]
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class ClassifiedImages: '
-                + ', '.join(bad_keys))
         if 'custom_classes' in _dict:
             args['custom_classes'] = _dict.get('custom_classes')
         if 'images_processed' in _dict:
             args['images_processed'] = _dict.get('images_processed')
         if 'images' in _dict:
             args['images'] = [
-                ClassifiedImage._from_dict(x) for x in (_dict.get('images'))
+                ClassifiedImage.from_dict(x) for x in _dict.get('images')
             ]
         else:
             raise ValueError(
@@ -927,7 +928,7 @@ class ClassifiedImages():
             )
         if 'warnings' in _dict:
             args['warnings'] = [
-                WarningInfo._from_dict(x) for x in (_dict.get('warnings'))
+                WarningInfo.from_dict(x) for x in _dict.get('warnings')
             ]
         return cls(**args)
 
@@ -945,9 +946,9 @@ class ClassifiedImages():
                    'images_processed') and self.images_processed is not None:
             _dict['images_processed'] = self.images_processed
         if hasattr(self, 'images') and self.images is not None:
-            _dict['images'] = [x._to_dict() for x in self.images]
+            _dict['images'] = [x.to_dict() for x in self.images]
         if hasattr(self, 'warnings') and self.warnings is not None:
-            _dict['warnings'] = [x._to_dict() for x in self.warnings]
+            _dict['warnings'] = [x.to_dict() for x in self.warnings]
         return _dict
 
     def _to_dict(self):
@@ -956,7 +957,7 @@ class ClassifiedImages():
 
     def __str__(self) -> str:
         """Return a `str` version of this ClassifiedImages object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'ClassifiedImages') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -1043,15 +1044,6 @@ class Classifier():
     def from_dict(cls, _dict: Dict) -> 'Classifier':
         """Initialize a Classifier object from a json dictionary."""
         args = {}
-        valid_keys = [
-            'classifier_id', 'name', 'owner', 'status', 'core_ml_enabled',
-            'explanation', 'created', 'classes', 'retrained', 'updated'
-        ]
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class Classifier: '
-                + ', '.join(bad_keys))
         if 'classifier_id' in _dict:
             args['classifier_id'] = _dict.get('classifier_id')
         else:
@@ -1074,9 +1066,7 @@ class Classifier():
         if 'created' in _dict:
             args['created'] = string_to_datetime(_dict.get('created'))
         if 'classes' in _dict:
-            args['classes'] = [
-                Class._from_dict(x) for x in (_dict.get('classes'))
-            ]
+            args['classes'] = [Class.from_dict(x) for x in _dict.get('classes')]
         if 'retrained' in _dict:
             args['retrained'] = string_to_datetime(_dict.get('retrained'))
         if 'updated' in _dict:
@@ -1107,7 +1097,7 @@ class Classifier():
         if hasattr(self, 'created') and self.created is not None:
             _dict['created'] = datetime_to_string(self.created)
         if hasattr(self, 'classes') and self.classes is not None:
-            _dict['classes'] = [x._to_dict() for x in self.classes]
+            _dict['classes'] = [x.to_dict() for x in self.classes]
         if hasattr(self, 'retrained') and self.retrained is not None:
             _dict['retrained'] = datetime_to_string(self.retrained)
         if hasattr(self, 'updated') and self.updated is not None:
@@ -1120,7 +1110,7 @@ class Classifier():
 
     def __str__(self) -> str:
         """Return a `str` version of this Classifier object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'Classifier') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -1132,14 +1122,14 @@ class Classifier():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-    class StatusEnum(Enum):
+    class StatusEnum(str, Enum):
         """
         Training status of classifier.
         """
-        READY = "ready"
-        TRAINING = "training"
-        RETRAINING = "retraining"
-        FAILED = "failed"
+        READY = 'ready'
+        TRAINING = 'training'
+        RETRAINING = 'retraining'
+        FAILED = 'failed'
 
 
 class ClassifierResult():
@@ -1168,12 +1158,6 @@ class ClassifierResult():
     def from_dict(cls, _dict: Dict) -> 'ClassifierResult':
         """Initialize a ClassifierResult object from a json dictionary."""
         args = {}
-        valid_keys = ['name', 'classifier_id', 'classes']
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class ClassifierResult: '
-                + ', '.join(bad_keys))
         if 'name' in _dict:
             args['name'] = _dict.get('name')
         else:
@@ -1188,7 +1172,7 @@ class ClassifierResult():
             )
         if 'classes' in _dict:
             args['classes'] = [
-                ClassResult._from_dict(x) for x in (_dict.get('classes'))
+                ClassResult.from_dict(x) for x in _dict.get('classes')
             ]
         else:
             raise ValueError(
@@ -1209,7 +1193,7 @@ class ClassifierResult():
         if hasattr(self, 'classifier_id') and self.classifier_id is not None:
             _dict['classifier_id'] = self.classifier_id
         if hasattr(self, 'classes') and self.classes is not None:
-            _dict['classes'] = [x._to_dict() for x in self.classes]
+            _dict['classes'] = [x.to_dict() for x in self.classes]
         return _dict
 
     def _to_dict(self):
@@ -1218,7 +1202,7 @@ class ClassifierResult():
 
     def __str__(self) -> str:
         """Return a `str` version of this ClassifierResult object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'ClassifierResult') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -1250,15 +1234,9 @@ class Classifiers():
     def from_dict(cls, _dict: Dict) -> 'Classifiers':
         """Initialize a Classifiers object from a json dictionary."""
         args = {}
-        valid_keys = ['classifiers']
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class Classifiers: '
-                + ', '.join(bad_keys))
         if 'classifiers' in _dict:
             args['classifiers'] = [
-                Classifier._from_dict(x) for x in (_dict.get('classifiers'))
+                Classifier.from_dict(x) for x in _dict.get('classifiers')
             ]
         else:
             raise ValueError(
@@ -1275,7 +1253,7 @@ class Classifiers():
         """Return a json dictionary representing this model."""
         _dict = {}
         if hasattr(self, 'classifiers') and self.classifiers is not None:
-            _dict['classifiers'] = [x._to_dict() for x in self.classifiers]
+            _dict['classifiers'] = [x.to_dict() for x in self.classifiers]
         return _dict
 
     def _to_dict(self):
@@ -1284,7 +1262,7 @@ class Classifiers():
 
     def __str__(self) -> str:
         """Return a `str` version of this Classifiers object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'Classifiers') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -1325,12 +1303,6 @@ class ErrorInfo():
     def from_dict(cls, _dict: Dict) -> 'ErrorInfo':
         """Initialize a ErrorInfo object from a json dictionary."""
         args = {}
-        valid_keys = ['code', 'description', 'error_id']
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class ErrorInfo: '
-                + ', '.join(bad_keys))
         if 'code' in _dict:
             args['code'] = _dict.get('code')
         else:
@@ -1371,7 +1343,7 @@ class ErrorInfo():
 
     def __str__(self) -> str:
         """Return a `str` version of this ErrorInfo object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'ErrorInfo') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
@@ -1406,12 +1378,6 @@ class WarningInfo():
     def from_dict(cls, _dict: Dict) -> 'WarningInfo':
         """Initialize a WarningInfo object from a json dictionary."""
         args = {}
-        valid_keys = ['warning_id', 'description']
-        bad_keys = set(_dict.keys()) - set(valid_keys)
-        if bad_keys:
-            raise ValueError(
-                'Unrecognized keys detected in dictionary for class WarningInfo: '
-                + ', '.join(bad_keys))
         if 'warning_id' in _dict:
             args['warning_id'] = _dict.get('warning_id')
         else:
@@ -1446,7 +1412,7 @@ class WarningInfo():
 
     def __str__(self) -> str:
         """Return a `str` version of this WarningInfo object."""
-        return json.dumps(self._to_dict(), indent=2)
+        return json.dumps(self.to_dict(), indent=2)
 
     def __eq__(self, other: 'WarningInfo') -> bool:
         """Return `true` when self and other are equal, false otherwise."""
